import type { EdgeBpmnSemantic, ElementsRegistry, ShapeBpmnSemantic } from 'bpmn-visualization';
/**
 * A general implementation for Path resolution.
 *
 * As it is generic and covers general use cases, its capabilities are limited.
 *
 * For the path resolution of single case/instance of a process, prefer {@link CasePathResolver}.
 */
export declare class PathResolver {
    private readonly elementsRegistry;
    constructor(elementsRegistry: ElementsRegistry);
    /**
     * If the `shapeIds` parameter contains ids related to edges, these ids are ignored and not returned as part of the visited edges.
     *
     * @param shapeIds the ids used to compute the visited edges
     */
    getVisitedEdges(shapeIds: string[]): string[];
}
/**
 * Provides path resolution for a single process instance/case.
 *
 * It is an enhanced implementation of {@link PathResolver} with resolution options and returns categorized `BpmnSemantic` objects.
 */
export declare class CasePathResolver {
    private readonly elementsRegistry;
    constructor(elementsRegistry: ElementsRegistry);
    compute(input: CasePathResolverInput): CasePathResolverOutput;
}
export type CasePathResolverInput = {
    /**
     * The IDs of elements (flowNodes/shapes and flows/edges) that are already completed. Non-existing ids will be silently ignored.
     *
     * `Completed` means that the element has been fully executed or definitively cancelled (for BPM engines that support this and allow cancelled elements to be continued).
     * No further user action or automation will update the element.
     */
    completedIds: string[];
};
export type CasePathResolverOutput = {
    /**
     * The `BpmnSemantic` objects retrieved from the model that relate to the ids passed in {@link CasePathResolverInput}.
     */
    provided: {
        completed: {
            shapes: ShapeBpmnSemantic[];
            edges: EdgeBpmnSemantic[];
        };
    };
    computed: {
        completed: {
            shapes: ShapeBpmnSemantic[];
            edges: EdgeBpmnSemantic[];
        };
    };
};
