/*
Copyright 2023 Bonitasoft S.A.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
const inferEdgeIds = (shapes) => {
    const incomingIds = [];
    const outgoingIds = [];
    for (const shape of shapes) {
        incomingIds.push(...shape.incomingIds);
        outgoingIds.push(...shape.outgoingIds);
    }
    return incomingIds.filter(incomingId => outgoingIds.includes(incomingId));
};
/**
 * A general implementation for Path resolution.
 *
 * As it is generic and covers general use cases, its capabilities are limited.
 *
 * For the path resolution of single case/instance of a process, prefer {@link CasePathResolver}.
 */
export class PathResolver {
    constructor(elementsRegistry) {
        Object.defineProperty(this, "elementsRegistry", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: elementsRegistry
        });
    }
    /**
     * If the `shapeIds` parameter contains ids related to edges, these ids are ignored and not returned as part of the visited edges.
     *
     * @param shapeIds the ids used to compute the visited edges
     */
    getVisitedEdges(shapeIds) {
        const shapes = this.elementsRegistry.getModelElementsByIds(shapeIds).filter(element => element.isShape);
        return inferEdgeIds(shapes);
    }
}
/**
 * Provides path resolution for a single process instance/case.
 *
 * It is an enhanced implementation of {@link PathResolver} with resolution options and returns categorized `BpmnSemantic` objects.
 */
export class CasePathResolver {
    constructor(elementsRegistry) {
        Object.defineProperty(this, "elementsRegistry", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: elementsRegistry
        });
    }
    compute(input) {
        const completedElements = this.elementsRegistry.getModelElementsByIds(input.completedIds);
        const completedShapes = completedElements.filter(element => element.isShape);
        const completedEdges = completedElements.filter(element => !element.isShape);
        const inputElementIds = new Set(completedElements.map(element => element.id));
        // infer edges from shapes
        const computedCompletedEdgeIds = inferEdgeIds(completedShapes).filter(id => !inputElementIds.has(id));
        const computedCompletedEdges = this.elementsRegistry.getModelElementsByIds(computedCompletedEdgeIds);
        // infer shapes from edges
        const computedCompletedShapeIds = completedEdges.flatMap(edge => [edge.sourceRefId, edge.targetRefId]).filter(id => !inputElementIds.has(id));
        const computedCompletedShapes = this.elementsRegistry.getModelElementsByIds(computedCompletedShapeIds);
        return {
            provided: {
                completed: {
                    shapes: completedShapes,
                    edges: completedEdges,
                },
            },
            computed: {
                completed: {
                    shapes: computedCompletedShapes,
                    edges: computedCompletedEdges,
                },
            },
        };
    }
}
