import { BpmnVisualization as BaseBpmnVisualization, type GlobalOptions as BaseGlobalOptions } from 'bpmn-visualization';
/**
 * Enforce the Plugin constructor signature.
 * Inspired from https://www.typescriptlang.org/docs/handbook/interfaces.html#difference-between-the-static-and-instance-sides-of-classes (deprecated page, but sill working).
 */
export type PluginConstructor = new (bpmnVisualization: BpmnVisualization, options: GlobalOptions) => Plugin;
/**
 * Plugin lifecycle:
 *   - construct
 *   - configure
 */
export interface Plugin {
    /** Returns the unique identifier of the plugin. It is not possible to use several plugins having the same identifier. */
    getPluginId(): string;
    /**
     * Implement this method to configure the plugin after initialization.
     * @param options The options passed to the BpmnVisualization instance, used to configure the plugin.
     */
    configure?: (options: GlobalOptions) => void;
}
/**
 * Let pass plugins configuration to {@link BpmnVisualization}.
 *
 * Use this type if you already have a dedicated custom `GlobalOptions` type extending the bpmn-visualization `GlobalOptions` type.
 * In this case, proceed as in the following example to add the plugins configuration to the custom `GlobalOptions`.
 *
 * ```ts
 * // Assuming you have a `CustomGlobalOptions` type extending the bpmn-visualization `GlobalOptions` type
 * type GlobalOptionsWithPluginsSupport = CustomGlobalOptions & PluginOptionExtension;
 * ```
 *
 * If you don't extend `GlobalOptions`, use {@link GlobalOptions} directly.
 */
export type PluginOptionExtension = {
    plugins?: PluginConstructor[];
};
export type GlobalOptions = BaseGlobalOptions & PluginOptionExtension;
/**
 * The identifiers of the plugins provided by `bpmn-visualization-addons`.
 * @since 0.7.0
 */
export type DefaultPlugins = 'css' | 'elements' | 'overlays' | 'style' | 'style-by-name';
/**
 * All possible identifiers that can be used to identify a plugin.
 * @since 0.7.0
 */
export type PluginIds = DefaultPlugins | (string & Record<never, never>);
export declare class BpmnVisualization extends BaseBpmnVisualization {
    private readonly plugins;
    constructor(options: GlobalOptions);
    getPlugin<T extends Plugin>(id: PluginIds): T;
    private readonly registerPlugins;
}
