import type { BpmnVisualization, Plugin } from '../plugins-support.js';
import type { StyleRegistry, StyleUpdate } from 'bpmn-visualization';
/**
 * Provide style operations on BPMN elements.
 *
 * This plugin is a wrapper that delegates the actual style operations to {@link BpmnElementsRegistry}.
 *
 * @since 0.7.0
 */
export declare class StylePlugin implements Plugin, StyleRegistry {
    private readonly styleRegistry;
    constructor(bpmnVisualization: BpmnVisualization);
    getPluginId(): string;
    updateStyle(bpmnElementIds: string | string[], styleUpdate: StyleUpdate): void;
    resetStyle(bpmnElementIds?: string | string[]): void;
}
/**
 * @since 0.7.0
 */
export interface StyleRegistryByName extends StyleRegistry {
    /**
     * Update the style of the BPMN elements with the given names.
     *
     * See {@link StyleRegistry.updateStyle} for more details.
     *
     * @param bpmnElementNames The name of the BPMN element(s) whose style must be updated.
     * @param styleUpdate The style properties to update.
     */
    updateStyle(bpmnElementNames: string | string[], styleUpdate: StyleUpdate): void;
    /**
     * Reset the style of the BPMN elements with the given names.
     *
     * See {@link StyleRegistry.resetStyle} for more details.
     *
     * @param bpmnElementNames The name of the BPMN element(s) whose style must be reset. When passing a nullish parameter, the style of all BPMN elements will be reset. Passing an empty array has no effect.
     */
    resetStyle(bpmnElementNames?: string | string[]): void;
}
/**
 * Provide style operations on BPMN elements, identifying them by name.
 *
 * This plugin is a wrapper that delegates the actual style operations to a {@link StyleRegistry} instance.
 * It uses the {@link BpmnElementsSearcher} to map names to ids.
 *
 * **WARNING**: This plugin does not currently allow you to configure deduplication or filtering of the elements corresponding to the names supplied as method parameters.
 * If a name corresponds to multiple elements, all matching elements are used, as implemented in {@link BpmnElementsSearcher.getElementsByNames}.
 * This is a known limitation of the current implementation.
 *
 * **IMPORTANT**: The mapping is currently not cached, nor pre-fetched after the BPMN source has been loaded.
 * So the implementation is not very effective. Caching and pre-fetch features will be implemented in the future.
 * See https://github.com/process-analytics/bpmn-visualization-addons/issues/4 for improvement.
 *
 * @since 0.7.0
 */
export declare class StyleByNamePlugin implements Plugin, StyleRegistryByName {
    private readonly searcher;
    private readonly styleRegistry;
    constructor(bpmnVisualization: BpmnVisualization);
    getPluginId(): string;
    updateStyle(bpmnElementNames: string | string[], styleUpdate: StyleUpdate): void;
    resetStyle(bpmnElementNames?: string | string[]): void;
}
