/*
Copyright 2024 Bonitasoft S.A.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
import { BpmnElementsSearcher } from '../bpmn-elements.js';
/**
 * Provide style operations on BPMN elements.
 *
 * This plugin is a wrapper that delegates the actual style operations to {@link BpmnElementsRegistry}.
 *
 * @since 0.7.0
 */
export class StylePlugin {
    constructor(bpmnVisualization) {
        Object.defineProperty(this, "styleRegistry", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.styleRegistry = bpmnVisualization.bpmnElementsRegistry;
    }
    getPluginId() {
        return 'style';
    }
    updateStyle(bpmnElementIds, styleUpdate) {
        this.styleRegistry.updateStyle(bpmnElementIds, styleUpdate);
    }
    resetStyle(bpmnElementIds) {
        this.styleRegistry.resetStyle(bpmnElementIds);
    }
}
/**
 * Provide style operations on BPMN elements, identifying them by name.
 *
 * This plugin is a wrapper that delegates the actual style operations to a {@link StyleRegistry} instance.
 * It uses the {@link BpmnElementsSearcher} to map names to ids.
 *
 * **WARNING**: This plugin does not currently allow you to configure deduplication or filtering of the elements corresponding to the names supplied as method parameters.
 * If a name corresponds to multiple elements, all matching elements are used, as implemented in {@link BpmnElementsSearcher.getElementsByNames}.
 * This is a known limitation of the current implementation.
 *
 * **IMPORTANT**: The mapping is currently not cached, nor pre-fetched after the BPMN source has been loaded.
 * So the implementation is not very effective. Caching and pre-fetch features will be implemented in the future.
 * See https://github.com/process-analytics/bpmn-visualization-addons/issues/4 for improvement.
 *
 * @since 0.7.0
 */
export class StyleByNamePlugin {
    constructor(bpmnVisualization) {
        Object.defineProperty(this, "searcher", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "styleRegistry", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.searcher = new BpmnElementsSearcher(bpmnVisualization.bpmnElementsRegistry);
        this.styleRegistry = bpmnVisualization.bpmnElementsRegistry;
    }
    getPluginId() {
        return 'style-by-name';
    }
    updateStyle(bpmnElementNames, styleUpdate) {
        const bpmnElements = this.searcher.getElementsByNames(bpmnElementNames);
        this.styleRegistry.updateStyle(bpmnElements.map(bpmnElement => bpmnElement.id), styleUpdate);
    }
    resetStyle(bpmnElementNames) {
        if (!bpmnElementNames) {
            this.styleRegistry.resetStyle();
            return;
        }
        const bpmnElements = this.searcher.getElementsByNames(bpmnElementNames);
        this.styleRegistry.resetStyle(bpmnElements.map(bpmnElement => bpmnElement.id));
    }
}
